// Copyright 2017 The Johns Hopkins University Applied Physics Laboratory.
// Licensed under the MIT License. See LICENSE.txt in the project root for full license information.

#include <tclap/CmdLine.h>

#include <eopcc/cloud_io.hpp>


void generate_reg_test(const std::string& input_file, int number_of_splits) {
  eopcc::PointCloud input;
  eopcc::Load(input_file, input);

  int split_size = input.size() / number_of_splits;

  std::random_device rd;
  std::default_random_engine gen(rd());

  eopcc::Extent extent(-4, 4);


  for (int i=0; i < number_of_splits; ++i) {
    int start = split_size * i;
    int end = split_size * (i + 1);

    eopcc::Point shift = extent.random_sample(gen);
    std::cout << "shift " << i << " : " << shift << std::endl;

    eopcc::PointCloud subcloud = input.subcloud(start, end);
    subcloud.translate(shift);

    eopcc::Write("split" + std::to_string(i) + ".ply", subcloud);
  }


}


int main(int argc, char* argv[]) {
  try {
    TCLAP::CmdLine cmd("generate-reg-test command line", ' ', "0.0");

    TCLAP::ValueArg<std::string> input_arg("", "in", "Point input filename", true, "", "string");
    TCLAP::ValueArg<int> num_splits_arg("s", "splits", "Number of splits", true, 2, "number");
    cmd.add(input_arg);
    cmd.add(num_splits_arg);

    cmd.parse(argc, argv);


    std::string input_file = input_arg.getValue();
    int num_splits = num_splits_arg.getValue();


    generate_reg_test(input_file, num_splits);


  } catch (TCLAP::ArgException &e) {
    std::cerr << "error: " << e.error() << " for arg " << e.argId() << std::endl;
  }

  return 0;
}
